<?php

declare(strict_types=1);

namespace Drupal\message_recipient_entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\message\MessageInterface;

/**
 * Trait for message template associated entity.
 */
trait MessageAssociatedEntityTrait {

  /**
   * {@inheritdoc}
   */
  public function hasAssociatedEntityField(MessageInterface $message): bool {
    return $message->hasField('message_associated_entity');
  }

  /**
   * Get the associated entity.
   *
   * @param \Drupal\message\MessageInterface $message
   *   The message entity.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface
   *   The associated entity
   */
  public function getAssociatedEntity(MessageInterface $message): ContentEntityInterface {
    return $message->get('message_associated_entity')
      ?->first()
      ?->get('entity')
      ?->getTarget()
      ?->getValue();
  }

}
