<?php

declare(strict_types=1);

namespace Drupal\message_recipient_entity\Plugin\MessageRecipient\RecipientsCollector;

use Drupal\Core\Entity\Query\QueryInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\message\MessageInterface;
use Drupal\message_recipient\Attribute\RecipientsCollector;
use Drupal\message_recipient_entity\ContentEntityUserRecipientsCollectorBase;
use Drupal\user\EntityOwnerInterface;

/**
 * Entity owner recipients collector.
 */
#[RecipientsCollector(
  id: 'entity_owner',
  type: 'user',
  category: 'content entity',
  allow_multiple: FALSE,
  label: new TranslatableMarkup('Entity owner'),
  description: new TranslatableMarkup("Collects the owner of the message's associated entity."),
)]
class EntityOwner extends ContentEntityUserRecipientsCollectorBase {

  /**
   * {@inheritdoc}
   */
  public function collect(MessageInterface $message): array {
    return array_values($this->query($message)->execute());
  }

  /**
   * {@inheritdoc}
   */
  public function query(MessageInterface $message): QueryInterface {
    $query = parent::query($message);
    $query->condition('uid', $this->getAssociatedEntity($message)->getOwnerId());
    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function isApplicable(MessageInterface $message): bool {
    if ($this->hasAssociatedEntityField($message)) {
      $associated_entity = $this->getAssociatedEntity($message);
      return $associated_entity instanceof EntityOwnerInterface;
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getSummary(): array {
    return [
      'recipient_collector' => [
        '#markup' => $this->description(),
      ],
    ] + parent::getSummary();
  }

}
