<?php

declare(strict_types=1);

namespace Drupal\message_recipient_ui\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\message\MessageTemplateInterface;
use Drupal\message_recipient\MessageTemplateRecipientsCollectors;
use Drupal\message_recipient\RecipientsCollectorInterface;
use Drupal\message_recipient\RecipientsCollectorManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Add form for recipients' collector.
 */
class RecipientsCollectorAddForm extends RecipientsCollectorFormBase {

  /**
   * The recipients collector manager.
   *
   * @var \Drupal\message_recipient\RecipientsCollectorManagerInterface
   */
  protected RecipientsCollectorManagerInterface $recipientsCollectorManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    $instance = parent::create($container);
    $instance->recipientsCollectorManager = $container->get('plugin.manager.message_recipient.recipients_collector');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, MessageTemplateInterface $message_template = NULL, string $recipients_collector = NULL): array {
    $form = parent::buildForm($form, $form_state, $message_template, $recipients_collector);

    $form['#title'] = $this->t('Add "%label" recipients collector to message template "%message_template"', [
      '%label' => $this->recipientsCollector->label(),
      '%message_template' => $message_template->label(),
    ]);
    $form['actions']['submit']['#value'] = $this->t('Add recipients collector');

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);

    // Save the configuration of the recipients' collection to the message
    // template.
    (new MessageTemplateRecipientsCollectors($this->messageTemplate))
      ->addRecipientsCollector($this->recipientsCollector->getPluginId(), $this->recipientsCollector->getConfiguration());

    $this->messenger()->addStatus($this->t('The recipients collector was successfully applied.'));
    $form_state->setRedirectUrl(new Url('message_recipient_ui.message_template.recipients_collectors', [
      'message_template' => $this->messageTemplate->id(),
    ]));
  }

  /**
   * {@inheritdoc}
   */
  protected function prepareRecipientsCollector(string $recipients_collector_id): RecipientsCollectorInterface {
    /** @var \Drupal\message_recipient\RecipientsCollectorInterface $recipients_collector */
    $recipients_collector = $this->recipientsCollectorManager->createInstance($recipients_collector_id);
    return $recipients_collector;
  }

}
