<?php

declare(strict_types=1);

namespace Drupal\message_recipient_ui\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\message\MessageTemplateInterface;
use Drupal\message_recipient\MessageTemplateRecipientsCollectors;
use Drupal\message_recipient\RecipientsCollectorInterface;

/**
 * Edit form for recipients' collector.
 */
class RecipientsCollectorEditForm extends RecipientsCollectorFormBase {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, MessageTemplateInterface $message_template = NULL, string $recipients_collector = NULL): array {
    $form = parent::buildForm($form, $form_state, $message_template, $recipients_collector);

    $form['#title'] = $this->t('Edit "%label" recipients collector on message template "%message_template"', [
      '%label' => $this->recipientsCollector->label(),
      '%message_template' => $message_template->label(),
    ]);
    $form['actions']['submit']['#value'] = $this->t('Update recipients collector');

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);

    // Update the configuration of the recipients' collection to the message
    // template.
    (new MessageTemplateRecipientsCollectors($this->messageTemplate))
      ->editRecipientsCollector($this->recipientsCollector->getUuid(), $this->recipientsCollector->getConfiguration());

    $this->messenger()->addStatus($this->t('The recipients collector was successfully updated.'));
    $form_state->setRedirectUrl(new Url('message_recipient_ui.message_template.recipients_collectors', [
      'message_template' => $this->messageTemplate->id(),
    ]));
  }

  /**
   * {@inheritdoc}
   */
  protected function prepareRecipientsCollector(string $recipients_collector_id): RecipientsCollectorInterface {
    return (new MessageTemplateRecipientsCollectors($this->messageTemplate))->getRecipientsCollector($recipients_collector_id);
  }

}
