<?php

declare(strict_types=1);

namespace Drupal\message_recipient\Attribute;

use Drupal\Component\Plugin\Attribute\Plugin;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\message_recipient\CollectorExtenderType;

/**
 * Defines a recipients collector extender attribute.
 */
#[\Attribute(\Attribute::TARGET_CLASS)]
class CollectorExtender extends Plugin {

  /**
   * Constructs a recipients' collector attribute.
   *
   * @param string $id
   *   The plugin ID.
   * @param \Drupal\message_recipient\CollectorExtenderType $stage
   *   The stage the extender is acting in, e.g. 'query_alter', 'post_collect'.
   * @param array $types
   *   (optional) The applicable recipients collector types, e.g. 'user',
   *   'email'.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup|null $label
   *   (optional) The human-readable name of the recipients' collector.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup|null $description
   *   (Optional) A brief description of the recipients' collector.
   */
  public function __construct(
    public readonly string $id,
    public readonly CollectorExtenderType $stage,
    public readonly array $types = [],
    public readonly ?TranslatableMarkup $label = NULL,
    public readonly ?TranslatableMarkup $description = NULL,
  ) {}

}
