<?php

declare(strict_types=1);

namespace Drupal\message_recipient\Attribute;

use Drupal\Component\Plugin\Attribute\Plugin;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Defines a recipients collector attribute.
 */
#[\Attribute(\Attribute::TARGET_CLASS)]
class RecipientsCollector extends Plugin {

  /**
   * Constructs a recipients' collector attribute.
   *
   * @param string $id
   *   The plugin ID.
   * @param string $type
   *   The recipient type, e.g. 'user', 'email'.
   * @param string $category
   *   The recipient category.
   * @param bool $allow_multiple
   *   Can the plugin be added multiple times to one message template.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup|null $label
   *   (optional) The human-readable name of the recipients' collector.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup|null $description
   *   (Optional) A brief description of the recipients' collector.
   */
  public function __construct(
    public readonly string $id,
    public readonly string $type,
    public readonly string $category,
    public readonly bool $allow_multiple = TRUE,
    public readonly ?TranslatableMarkup $label = NULL,
    public readonly ?TranslatableMarkup $description = NULL,
  ) {}

}
