<?php

declare(strict_types=1);

namespace Drupal\message_recipient;

use Drupal\Core\Plugin\DefaultLazyPluginCollection;

/**
 * A collection of collector's extenders for a recipients' collectors.
 */
class CollectorExtenderPluginCollection extends DefaultLazyPluginCollection {

  /**
   * The recipients' collector.
   *
   * @var \Drupal\message_recipient\RecipientsCollectorInterface
   */
  protected RecipientsCollectorInterface $recipientsCollector;

  /**
   * Constructs a new CollectorExtenderPluginCollection object.
   *
   * @param \Drupal\message_recipient\CollectorExtenderManagerInterface $manager
   *   The collector extender plugin manager.
   * @param \Drupal\message_recipient\RecipientsCollectorInterface $recipients_collector
   *   The recipients' collector that hosts this collection of extenders.
   * @param array $configurations
   *   The extenders' configurations.
   */
  public function __construct(CollectorExtenderManagerInterface $manager, RecipientsCollectorInterface $recipients_collector, array $configurations = []) {
    parent::__construct($manager, $configurations);
    $this->recipientsCollector = $recipients_collector;
  }

  /**
   * {@inheritdoc}
   *
   * @return \Drupal\message_recipient\CollectorExtenderInterface
   *   The collector extender.
   */
  public function &get($instance_id): CollectorExtenderInterface {
    return parent::get($instance_id);
  }

  /**
   * {@inheritdoc}
   */
  protected function initializePlugin($instance_id): void {
    parent::initializePlugin($instance_id);
    $this->pluginInstances[$instance_id]->initialize($this->recipientsCollector);
  }

}
