<?php

declare(strict_types=1);

namespace Drupal\message_recipient;

use Drupal\Core\Entity\Query\QueryInterface;
use Drupal\Message\MessageInterface;

/**
 * Trait for a collector extender that alters a query.
 */
trait CollectorExtenderQueryTrait {

  /**
   * Alters a recipients' collector query.
   *
   * @param \Drupal\Core\Entity\Query\QueryInterface $query
   *   The recipients' collector query to alter.
   * @param \Drupal\message\MessageInterface $message
   *   The message entity.
   */
  public function alterQuery(QueryInterface &$query, MessageInterface $message): void {
    $extenders = $this->getExtenders();
    /** @var \Drupal\message_recipient\CollectorExtenderInterface $extender */
    foreach ($extenders as $extender) {
      if ($extender->getStage() === CollectorExtenderType::QUERY_ALTER
        && $extender->isApplicable($message)) {
        $extender->queryAlter($query, $message);
      }
    }
  }

}
