<?php

declare(strict_types=1);

namespace Drupal\message_recipient;

use Drupal\message\Entity\MessageTemplate;
use Drupal\message\MessageInterface;

/**
 * Collects the recipients for a message.
 */
class MessageRecipientsCollector implements MessageRecipientsCollectorInterface {

  /**
   * The recipients collector manager.
   *
   * @var \Drupal\message_recipient\RecipientsCollectorManagerInterface
   */
  protected RecipientsCollectorManagerInterface $recipientsCollectorManager;

  /**
   * Constructs a new RecipientsCollectorAddForm.
   *
   * @param \Drupal\message_recipient\RecipientsCollectorManagerInterface $recipients_collector_manager
   *   The recipients collector manager.
   */
  public function __construct(RecipientsCollectorManagerInterface $recipients_collector_manager) {
    $this->recipientsCollectorManager = $recipients_collector_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getRecipients(MessageInterface $message): array {
    $message_template = MessageTemplate::load($message->bundle());
    $message_template_recipients_collectors = (new MessageTemplateRecipientsCollectors($message_template))
      ->getRecipientsCollectors();
    $final_recipients = [];
    /** @var \Drupal\message_recipient\RecipientsCollectorInterface $recipients_collector */
    foreach ($message_template_recipients_collectors as $recipients_collector) {
      $recipients = [];
      if ($recipients_collector->isApplicable($message)) {
        if (!isset($final_recipients[$recipients_collector->getType()])) {
          $final_recipients[$recipients_collector->getType()] = [];
        }
        $recipients = $recipients_collector->collect($message);
        $recipients_collector->performPostCollect($recipients, $message);
        $final_recipients[$recipients_collector->getType()] = array_merge($final_recipients[$recipients_collector->getType()], $recipients);
      }
    }

    return $this->filterRecipients($final_recipients);
  }

  /**
   * Filter recipients by removing duplicates and excluding anonymous user.
   *
   * @param array $recipients
   *   The recipients' lists keyed by type.
   *
   * @return array
   *   The filtered recipients lists. Each list is keyed by its type.
   */
  protected function filterRecipients(array $recipients): array {
    $filtered_recipients = [];
    foreach ($recipients as $type => $recipients_list) {
      $recipients_list = array_unique($recipients_list);
      if ($type === 'user') {
        $recipients_list = array_diff($recipients_list, [0]);
      }
      $filtered_recipients[$type] = $recipients_list;
    }

    return $filtered_recipients;
  }

}
