<?php

declare(strict_types=1);

namespace Drupal\message_recipient\Plugin\MessageRecipient\CollectorExtender;

use Drupal\Core\Entity\Query\QueryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\message\MessageInterface;
use Drupal\message_recipient\Attribute\CollectorExtender;
use Drupal\message_recipient\CollectorExtenderBase;
use Drupal\message_recipient\CollectorExtenderInterface;
use Drupal\message_recipient\CollectorExtenderType;
use Drupal\message_recipient\RecipientsCollectorInterface;

/**
 * Include blocked users collector extender.
 */
#[CollectorExtender(
  id: 'include_blocked_users',
  stage: CollectorExtenderType::QUERY_ALTER,
  types: ['user'],
  label: new TranslatableMarkup('Include blocked users'),
  description: new TranslatableMarkup('Includes any blocked user collected by this recipients collector.'),
)]
class IncludeBlocked extends CollectorExtenderBase implements CollectorExtenderInterface {

  /**
   * {@inheritdoc}
   */
  public function queryAlter(QueryInterface &$query, MessageInterface $message): void {
    if ($this->configuration['include_blocked'] !== TRUE) {
      $query->condition('status', 1);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'include_blocked' => FALSE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state, RecipientsCollectorInterface $recipients_collector): array {
    $form['include_blocked'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Include blocked user'),
      '#default_value' => $this->configuration['include_blocked'],
      '#description' => $this->t("When this option is selected, blocked users won't be filtered out from the recipients collected by this collector."),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state, RecipientsCollectorInterface $recipients_collector): void {
    $this->configuration['include_blocked'] = (bool) $form_state->getValue('include_blocked');
    parent::submitConfigurationForm($form, $form_state, $recipients_collector);
  }

  /**
   * {@inheritdoc}
   */
  public function getSummary(): array {
    return $this->configuration['include_blocked']
      ? ['#markup' => $this->label()]
      : [];
  }

}
