<?php

declare(strict_types=1);

namespace Drupal\message_recipient\Plugin\MessageRecipient\RecipientsCollector;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\message\MessageInterface;
use Drupal\message_recipient\Attribute\RecipientsCollector;
use Drupal\message_recipient\RecipientsCollectorBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Site mail recipients collector.
 */
#[RecipientsCollector(
  id: 'site_mail',
  type: 'email',
  category: 'general',
  allow_multiple: FALSE,
  label: new TranslatableMarkup('Site mail'),
  description: new TranslatableMarkup('Collects site mail.'),
)]
class SiteMail extends RecipientsCollectorBase {

  /**
   * The config factory used by the config entity query.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected ConfigFactoryInterface $configFactory;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->configFactory = $container->get('config.factory');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function collect(MessageInterface $message): array {
    return [$this->configFactory->get('system.site')->get('mail')];
  }

  /**
   * {@inheritdoc}
   */
  public function isApplicable(MessageInterface $message): bool {
    return TRUE;
  }

}
