<?php

declare(strict_types=1);

namespace Drupal\message_recipient;

use Drupal\Component\Utility\Html;
use Drupal\Component\Utility\Unicode;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\message_recipient\Attribute\RecipientsCollector;

/**
 * Plugin type manager for recipients' collector.
 */
class RecipientsCollectorManager extends DefaultPluginManager implements RecipientsCollectorManagerInterface {

  /**
   * Constructs a new RecipientsCollectorManager.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/MessageRecipient/RecipientsCollector', $namespaces, $module_handler, RecipientsCollectorInterface::class, RecipientsCollector::class);
    $this->alterInfo('message_recipient_recipients_collector_info');
    $this->setCacheBackend($cache_backend, 'message_recipient_recipients_collector_plugins');
  }

  /**
   * {@inheritdoc}
   */
  public function getDefinitionById(string $id): array {
    return $this->getDefinitions()[$id];
  }

  /**
   * {@inheritdoc}
   */
  public function getDefinitionsListOptionsGroupedByCategory(): array {
    $options = [];
    foreach ($this->getDefinitions() as $plugin_id => $plugin_definition) {
      $options[Unicode::ucfirst($plugin_definition['category'])][$plugin_id] = Html::escape($plugin_definition['label']);
    }
    foreach ($options as $key => $value) {
      asort($options[$key]);
    }
    return $options;
  }

}
