<?php

declare(strict_types=1);

namespace Drupal\message_recipient;

use Drupal\Core\Plugin\DefaultLazyPluginCollection;
use Drupal\message\MessageTemplateInterface;

/**
 * A collection of recipients' collectors stored in a message template.
 */
class RecipientsCollectorPluginCollection extends DefaultLazyPluginCollection {

  /**
   * The message template that holds these recipients' collector collections.
   *
   * @var \Drupal\message\MessageTemplateInterface
   */
  protected MessageTemplateInterface $messageTemplate;

  /**
   * Constructs a new RecipientsCollectorPluginCollection object.
   *
   * @param \Drupal\message_recipient\RecipientsCollectorManagerInterface $manager
   *   The recipients' collector plugin manager.
   * @param \Drupal\message\MessageTemplateInterface $message_template
   *   The message template that hosts this collection of recipient's
   *   collectors.
   * @param array $configurations
   *   The configurations for the recipients' collectors.
   */
  public function __construct(RecipientsCollectorManagerInterface $manager, MessageTemplateInterface $message_template, array $configurations = []) {
    parent::__construct($manager, $configurations);
    $this->messageTemplate = $message_template;
  }

  /**
   * {@inheritdoc}
   *
   * @return \Drupal\message_recipient\RecipientsCollectorInterface
   *   The recipients' collector.
   */
  public function &get($instance_id): RecipientsCollectorInterface {
    return parent::get($instance_id);
  }

  /**
   * {@inheritdoc}
   */
  protected function initializePlugin($instance_id): void {
    parent::initializePlugin($instance_id);
    $this->pluginInstances[$instance_id]->initialize($this->messageTemplate);
  }

}
